@@ -13,18 +13,20 @@ foreach my $key (sort keys %{$m_hrLng->{$lg}}) {
       } unless $key eq 'action';
 }
 my @l;
-$m_sContent .= '<div align="center">';
+print '<div align="center" class="ShowTables" style="margin-top:1.65em;">';
 
 foreach my $key (sort keys %{$m_hrLng}) {
     push @l, $key;
-    $m_sContent .= a({href => "$ENV{SCRIPT_NAME}?action=translate&lang=$key"}, $key) . '&#160;|&#160;';
+    print a({href => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=translate&lang=$key&ajax=true','translate','$key')"}, $key) . '&#160;|&#160;';
 }
-$m_sContent .= a({href => "$ENV{SCRIPT_NAME}?action=showaddTranslation"}, translate('addTranslation')) . '&#160;';
+my $addtranslate = translate('addTranslation');
+print a({href => "javascript:requestURI('$ENV{SCRIPT_NAME}?action=showaddTranslation&ajax=true','$m_sAction','$addtranslate')"}, $addtranslate) . '&#160;';
 show_form(
           -HEADER   => qq(&#160;),
           -ACCEPT   => \&on_valid_form,
           -CHECK    => (param('checkFormsddfsds') ? 1 : 0),
           -LANGUAGE => $ACCEPT_LANGUAGE,
+          -ONSUBMIT => "submitForm(this,'$m_sAction','".translate('translate')."');return false;",
           -FIELDS   => [
                       {
                        -LABEL   => 'action',
@@ -46,51 +48,32 @@ show_form(
           -BUTTONS => [{-name => translate('save')},],
           -FOOTER  => '<br/>',
 );
-my $htm = GetHtml();
-if (defined $htm) {
-    my %parameter = (
-                     path   => $m_hrSettings->{cgi}{bin} . '/templates',
-                     style  => $m_sStyle,
-                     title  => translate('translate'),
-                     server => $m_hrSettings->{serverName},
-                     id     => 'translate',
-                     class  => 'max',
-    );
-    my $window = new HTML::Window(\%parameter);
-    $window->set_closeable(0);
-    $window->set_moveable(0);
-    $window->set_resizeable(0);
-    $m_sContent .= $window->windowHeader();
-    $m_sContent .= qq|<div align="left">$htm</div></div>|;
-    $m_sContent .= $window->windowFooter();
-}
+print qq|</div>|;
 
 sub on_valid_form
 {
+    my $savetranslate = translate('savetranslate');
     my $rs =
       ($m_hrSettings->{cgi}{mod_rewrite})
       ? '/translate.html'
-      : "$ENV{SCRIPT_NAME}?action=translate";
+      : "javascript:requestURI('$ENV{SCRIPT_NAME}?action=translate','$m_sAction','$savetranslate')";
     my %parameter = (
                      path   => $m_hrSettings->{cgi}{bin} . '/templates',
                      style  => $m_sStyle,
-                     title  => translate('savetranslate'),
+                     title  => $sveTranslate,
                      server => $m_hrSettings->{serverName},
                      id     => 'savetranslate',
                      class  => 'max',
     );
-    my $window = new HTML::Window(\%parameter);
-    $m_sContent .= $window->windowHeader();
-    $m_sContent .= '<br/><div align="center" style="width:75%;"><b>' . translate('Done') . qq(&#160;<a href="$rs">) . translate('next') . '</a></b><br/><div align="left">';
+    print '<br/><div align="center" style="width:75%;"><b>' . translate('Done') . qq(&#160;<a href="$rs">) . translate('next') . '</a></b><br/><div align="left">';
     my @entrys = param();
     for (my $i = 0; $i <= $#entrys; $i++) {
         my $rkey = lc $entrys[$i];
         delete $m_hrLng->{$lg}{$entrys[$i]};
-        $m_sContent .= "$rkey: " . param($entrys[$i]) . '<br/>' unless (($rkey eq 'action') or ($rkey eq 'checkFormsddfsds'));
+        print "$rkey: " . param($entrys[$i]) . '<br/>' unless (($rkey eq 'action') or ($rkey eq 'checkFormsddfsds'));
         $m_hrLng->{$lg}{$rkey} = param($entrys[$i]) unless ($rkey eq 'action' or ($rkey eq 'checkFormsddfsds'));
     }
     saveTranslate($m_hrSettings->{translate});
-    $m_sContent .= '</div></div>';
-    $m_sContent .= $window->windowFooter();
+    print '</div></div>';
 }
 1;
