@@ -1,4 +1,5 @@
 $VAR1 = {
           'guest' => {},
-          'admin' => {};
+          'admin' => {}
+        };
 $session =$VAR1;
\ No newline at end of file
