@@ -2,8 +2,8 @@
 use strict;
 use utf8;
 use warnings;
-#use CGI::Carp qw(fatalsToBrowser);
+use CGI::Carp qw(fatalsToBrowser);
 use lib qw(lib);
 use MySQL::Admin::GUI;
 ContentHeader("%PATH%/config/settings.pl");
-print Body();
\ No newline at end of file
+&Body();
\ No newline at end of file
