@@ -8,7 +8,7 @@ CREATE TABLE `actions` (
   PRIMARY KEY (`id`),
   UNIQUE KEY `action_2` (`action`),
   KEY `action` (`action`)
-) ENGINE=InnoDB AUTO_INCREMENT=3161 DEFAULT CHARSET=utf8;
+) ENGINE=InnoDB AUTO_INCREMENT=1567 DEFAULT CHARSET=utf8;
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','AddFulltext','1');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','AnalyzeTable','2');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','AddPrimaryKey','3');
@@ -69,6 +69,58 @@ INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('login
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('quickbar','quickbar.pl','quickbar','5','main','58');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','ShowNewTable','117');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('downLoadFile','tables.pl','downLoadFile','5','downLoadFile','1288');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('news','news.pl','Blog','6','show','1512');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('settings','quick.pl','Settings','5','main','1513');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('addNews','news.pl','newMessage','6','addNews','1514');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('admin','admin.pl','adminCenter','5','main','1515');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('delete','news.pl','blog','6','deleteNews','1516');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('edit','news.pl','blog','6','editNews','1517');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('saveedit','news.pl','blog','6','saveedit','1518');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('reply','news.pl','blog','6','replyNews','1519');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('profile','profile.pl','Profile','1','main','1520');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('reg','reg.pl','register','0','reg','1521');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('addReply','news.pl','blog','6','addReply','1522');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showthread','news.pl','blog','6','showMessage','1523');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('verify','reg.pl','verify','0','verify','1524');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('fulltext','search.pl','search','0','fulltext','1525');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('newTreeviewEntry','editTree.pl','newTreeViewEntry','5','newTreeviewEntry','1526');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('saveTreeviewEntry','editTree.pl','saveTreeviewEntry','5','saveTreeviewEntry','1527');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('editTreeview','editTree.pl','editTreeview','5','editTreeview','1528');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('addTreeviewEntry','editTree.pl','addTreeviewEntry','5','addTreeviewEntry','1529');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('editTreeviewEntry','editTree.pl','editTreeviewEntry','5','editTreeviewEntry','1530');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('deleteTreeviewEntry','editTree.pl','deleteTreeviewEntry','5','deleteTreeviewEntry','1531');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('upEntry','editTree.pl','upEntry','5','upEntry','1532');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('downEntry','editTree.pl','downEntry','5','downEntry','1533');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('links','links.pl','Bookmarks','0','ShowBookmarks','1534');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('env','env.pl','env','5','main','1535');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('lostpass','login.pl','lostpass','0','lostpass','1536');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('getpass','login.pl','getpass','0','getpass','1537');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showDir','files.pl','Files','5','showDir','1538');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('FileOpen','files.pl','FileOpen','5','FileOpen','1539');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('newFile','files.pl','newFile','5','newFile','1540');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('saveFile','files.pl','saveFile','5','saveFile','1541');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showMessage','news.pl','blog','6','main','1542');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('chmodFile','files.pl','chmodFile','5','chmodFile','1543');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('deleteFile','files.pl','deleteFile','5','deleteFile','1544');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('makeDir','files.pl','Files','5','makeDir','1545');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('newGbookEntry','gbook.pl','gbook','6','newGbookEntry','1546');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('addnewGbookEntry','gbook.pl','gbook','6','addnewGbookEntry','1547');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('gbook','gbook.pl','gbook','6','showGbook','1548');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('deleteExploit','admin.pl','Admin','5','deleteExploit','1549');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ImportOperaBookmarks','links.pl','ImportOperaBookmarks','5','ImportOperaBookmarks','1550');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('linkseditTreeview','editTree.pl','linkseditTreeview','5','linkseditTreeview','1551');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('EditFile','files.pl','EditAction','5','EditFile','1552');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ExportOperaBookmarks','links.pl','ExportOperaBookmarks','0','ExportOperaBookmarks','1553');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('MoveTreeViewEntry','editTree.pl','MoveTreeViewEntry','5','MoveTreeViewEntry','1554');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('chownFile','files.pl','chownFile','5','chownFile','1556');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('ImportFireFoxBookmarks','links.pl','ImportFireFoxBookmarks','5','ImportFireFoxBookmarks','1557');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('rebuildtrash','news.pl','weblog','6','rebuildtrash','1558');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('trash','news.pl','trash','6','trash','1559');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('showaddTranslation','addtranslate.pl','showaddTranslation','5','main','1560');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('translate','translate.pl','translate','5','main','1561');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('deleteTreeviewEntrys','editTree.pl','Edit','5','deleteTreeviewEntrys','1562');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('makeUser','reg.pl','register','0','make','1565');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`sub`,`id`) values('navigation','navigation.pl','navigation','0','main','1566');
 
 CREATE TABLE `actions_set` (
   `action` varchar(25) NOT NULL,
@@ -78,7 +130,7 @@ CREATE TABLE `actions_set` (
   PRIMARY KEY (`id`),
   KEY `foreign_action` (`foreign_action`),
   CONSTRAINT `actions_set_ibfk_1` FOREIGN KEY (`foreign_action`) REFERENCES `actions` (`action`) ON DELETE CASCADE ON UPDATE CASCADE
-) ENGINE=InnoDB AUTO_INCREMENT=139 DEFAULT CHARSET=utf8;
+) ENGINE=InnoDB AUTO_INCREMENT=415 DEFAULT CHARSET=utf8;
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddFulltext','AddFulltext','content','1');
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AnalyzeTable','AnalyzeTable','content','2');
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddPrimaryKey','AddPrimaryKey','content','3');
@@ -135,87 +187,71 @@ INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('s
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showProfile','showProfile','content','54');
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('searchHelpTopic','searchHelpTopic','content','56');
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowNewTable','ShowNewTable','content','57');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddFulltext','login','login','58');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AnalyzeTable','login','login','59');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddPrimaryKey','login','login','60');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ChangeCol','login','login','61');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ChooseDataBase','login','login','62');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropTable','login','login','63');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DeleteEntry','login','login','64');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropCol','login','login','65');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowDumpTable','login','login','66');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ExecSql','login','login','67');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditTable','login','login','68');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditEntry','login','login','69');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('NewTable','login','login','70');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('OptimizeTable','login','login','71');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('RepairTable','login','login','72');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropFulltext','login','login','73');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowTables','login','login','74');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowTableDetails','login','login','75');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowTable','login','login','76');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('TruncateTable','login','login','77');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowProcesslist','login','login','78');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddIndex','login','login','79');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropIndex','login','login','80');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddUnique','login','login','81');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowNewEntry','login','login','82');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('MultipleAction','login','login','83');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowDumpDatabase','login','login','84');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditAction','login','login','85');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('NewDatabase','login','login','86');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveNewIndex','login','login','87');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowRights','login','login','88');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveRights','login','login','89');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowUsers','login','login','90');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DeleteUser','login','login','91');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropDatabase','login','login','92');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowDatabases','login','login','93');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowVariables','login','login','94');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showLogin','login','login','95');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showProfile','login','login','96');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('searchHelpTopic','login','login','97');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddFulltext','quickbar','menuBar','98');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AnalyzeTable','quickbar','menuBar','99');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddPrimaryKey','quickbar','menuBar','100');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ChangeCol','quickbar','menuBar','101');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ChooseDataBase','quickbar','menuBar','102');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropTable','quickbar','menuBar','103');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DeleteEntry','quickbar','menuBar','104');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropCol','quickbar','menuBar','105');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowDumpTable','quickbar','menuBar','106');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ExecSql','quickbar','menuBar','107');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditTable','quickbar','menuBar','108');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditEntry','quickbar','menuBar','109');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('NewTable','quickbar','menuBar','110');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('OptimizeTable','quickbar','menuBar','111');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('RepairTable','quickbar','menuBar','112');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropFulltext','quickbar','menuBar','113');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowTables','quickbar','menuBar','114');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowTableDetails','quickbar','menuBar','115');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowTable','quickbar','menuBar','116');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('TruncateTable','quickbar','menuBar','117');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowProcesslist','quickbar','menuBar','118');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddIndex','quickbar','menuBar','119');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropIndex','quickbar','menuBar','120');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('AddUnique','quickbar','menuBar','121');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowNewEntry','quickbar','menuBar','122');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('MultipleAction','quickbar','menuBar','123');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowDumpDatabase','quickbar','menuBar','124');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditAction','quickbar','menuBar','125');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('NewDatabase','quickbar','menuBar','126');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveNewIndex','quickbar','menuBar','127');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowRights','quickbar','menuBar','128');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('SaveRights','quickbar','menuBar','129');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowUsers','quickbar','menuBar','130');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DeleteUser','quickbar','menuBar','131');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('DropDatabase','quickbar','menuBar','132');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowDatabases','quickbar','menuBar','133');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ShowVariables','quickbar','menuBar','134');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showLogin','quickbar','menuBar','135');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showProfile','quickbar','menuBar','136');
-INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('searchHelpTopic','quickbar','menuBar','137');
 INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('downLoadFile','downLoadFile','content','138');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('news','news','content','139');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('settings','settings','content','140');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('addNews','addNews','content','141');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('admin','admin','content','142');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('delete','delete','content','143');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('edit','edit','content','144');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('saveedit','saveedit','content','145');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('reply','reply','content','146');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('profile','profile','content','147');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('reg','reg','content','148');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('addReply','addReply','content','149');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showthread','showthread','content','150');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('verify','verify','content','152');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('fulltext','fulltext','content','153');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('newTreeviewEntry','newTreeviewEntry','content','154');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('saveTreeviewEntry','saveTreeviewEntry','content','155');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('editTreeview','editTreeview','content','156');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('addTreeviewEntry','addTreeviewEntry','content','157');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('editTreeviewEntry','editTreeviewEntry','content','158');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('deleteTreeviewEntry','deleteTreeviewEntry','content','159');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('upEntry','upEntry','content','160');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('downEntry','downEntry','content','161');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('links','links','content','162');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('env','env','content','163');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('lostpass','lostpass','content','164');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('getpass','getpass','content','165');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showDir','showDir','content','166');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('FileOpen','FileOpen','content','167');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('newFile','newFile','content','168');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('saveFile','saveFile','content','169');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showMessage','showMessage','content','170');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('chmodFile','chmodFile','content','171');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('deleteFile','deleteFile','content','172');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('makeDir','makeDir','content','173');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('newGbookEntry','newGbookEntry','content','174');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('addnewGbookEntry','addnewGbookEntry','content','175');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('gbook','gbook','content','176');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('deleteExploit','deleteExploit','content','177');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ImportOperaBookmarks','ImportOperaBookmarks','content','179');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('linkseditTreeview','linkseditTreeview','content','180');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('EditFile','EditFile','content','181');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ExportOperaBookmarks','ExportOperaBookmarks','content','182');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('MoveTreeViewEntry','MoveTreeViewEntry','content','183');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('chownFile','chownFile','content','184');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('ImportFireFoxBookmarks','ImportFireFoxBookmarks','content','185');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('rebuildtrash','rebuildtrash','content','186');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('trash','trash','content','187');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showaddTranslation','showaddTranslation','content','188');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('translate','translate','content','189');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('deleteTreeviewEntrys','deleteTreeviewEntrys','content','190');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('makeUser','makeUser','content','244');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('default','navigation','treeview','412');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('default','login','login','413');
+INSERT INTO `actions_set` (`action`,`foreign_action`,`output_id`,`id`) values('showDatabases','quickbar','quickbar','414');
+
+CREATE TABLE `cats` (
+  `name` varchar(100) NOT NULL DEFAULT '',
+  `right` int(11) NOT NULL DEFAULT '0',
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  PRIMARY KEY (`id`)
+) ENGINE=MyISAM AUTO_INCREMENT=6 DEFAULT CHARSET=utf8;
+INSERT INTO `cats` (`name`,`right`,`id`) values('news','0','1');
+INSERT INTO `cats` (`name`,`right`,`id`) values('member','1','2');
+INSERT INTO `cats` (`name`,`right`,`id`) values('draft','2','5');
 
 CREATE TABLE `exploit` (
   `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
@@ -227,11 +263,63 @@ CREATE TABLE `exploit` (
   PRIMARY KEY (`id`),
   UNIQUE KEY `id` (`id`),
   FULLTEXT KEY `remote_addr` (`remote_addr`)
-) ENGINE=MyISAM AUTO_INCREMENT=5 DEFAULT CHARSET=utf8;
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-06-26 07:09:49','http://localhost/?perl/mysql.pl?action=showDatabases','127.0.0.1','action=showDatabases','1','14');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-06-27 10:52:29','http://localhost/?perl/mysql.pl?action=ShowTables','127.0.0.1','action=ShowTables','2','4');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-06-25 18:28:13','http://localhost/?/perl/mysql.pl?action=logout','127.0.0.1','action=logout','3','2');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-06-25 19:05:36','http://localhost/?perl/mysql.pl?action=ShowUsers','127.0.0.1','action=ShowUsers','4','2');
+) ENGINE=MyISAM AUTO_INCREMENT=16 DEFAULT CHARSET=utf8;
+
+CREATE TABLE `flood` (
+  `remote_addr` text NOT NULL,
+  `ti` text NOT NULL,
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  PRIMARY KEY (`id`)
+) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
+
+CREATE TABLE `gbook` (
+  `title` varchar(50) NOT NULL DEFAULT '',
+  `body` text NOT NULL,
+  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+  `user` text NOT NULL,
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  PRIMARY KEY (`id`),
+  FULLTEXT KEY `title` (`title`,`body`)
+) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
+INSERT INTO `gbook` (`title`,`body`,`date`,`user`,`id`) values('Überschrift','Erstelle Deine Nachricht.','2015-09-22 07:47:36','admin','1');
+INSERT INTO `gbook` (`title`,`body`,`date`,`user`,`id`) values('Überschrift','Erstelle Deine Nachricht. ä#+üö','2015-09-22 19:41:09','admin','2');
+
+CREATE TABLE `navigation` (
+  `title` varchar(100) NOT NULL DEFAULT '',
+  `action` varchar(100) NOT NULL DEFAULT '',
+  `src` varchar(100) NOT NULL DEFAULT '',
+  `right` int(11) NOT NULL DEFAULT '0',
+  `position` int(5) DEFAULT NULL,
+  `submenu` varchar(100) DEFAULT NULL,
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  `target` int(11) DEFAULT NULL,
+  PRIMARY KEY (`id`)
+) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8;
+INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('blog','news','news.png','6','1','','1','0');
+INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('Admin','admin','admin.png','5','3','submenuadmin','2','0');
+INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('properties','profile','profile.png','1','5','','3','0');
+INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('links','links','link.png','0','4','','5','0');
+INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('gbook','gbook','link.png','6','8','','7','0');
+INSERT INTO `navigation` (`title`,`action`,`src`,`right`,`position`,`submenu`,`id`,`target`) values('ShowDatabases','ShowDatabases','link.png','5','2','submenu_database','8','0');
+
+CREATE TABLE `news` (
+  `title` varchar(100) NOT NULL DEFAULT '',
+  `body` text NOT NULL,
+  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+  `user` text NOT NULL,
+  `right` int(11) NOT NULL DEFAULT '0',
+  `attach` varchar(100) NOT NULL DEFAULT '0',
+  `cat` varchar(25) NOT NULL DEFAULT 'news',
+  `action` varchar(50) NOT NULL DEFAULT 'main',
+  `sticky` int(1) NOT NULL DEFAULT '0',
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  `format` varchar(10) NOT NULL DEFAULT 'bbcode',
+  PRIMARY KEY (`id`),
+  FULLTEXT KEY `title` (`title`,`body`)
+) ENGINE=MyISAM AUTO_INCREMENT=24 DEFAULT CHARSET=utf8;
+INSERT INTO `news` (`title`,`body`,`date`,`user`,`right`,`attach`,`cat`,`action`,`sticky`,`id`,`format`) values('Überschrift','Erstelle Deine Nachricht#äü','2015-10-03 11:35:40','admin','0','0','news','news','0','22','bbcode');
+INSERT INTO `news` (`title`,`body`,`date`,`user`,`right`,`attach`,`cat`,`action`,`sticky`,`id`,`format`) values('Überschrift','Erstelle Deine Nachrichtddgfg','2015-10-07 18:34:36','admin','0','0','news','news','0','23','bbcode');
+INSERT INTO `news` (`title`,`body`,`date`,`user`,`right`,`attach`,`cat`,`action`,`sticky`,`id`,`format`) values('Überschrift','Erstelle Deine Nachricht','2015-09-29 15:13:18','admin','0','0','news','news','0','18','bbcode');
 
 CREATE TABLE `querys` (
   `title` varchar(100) NOT NULL DEFAULT '',
@@ -242,6 +330,29 @@ CREATE TABLE `querys` (
   PRIMARY KEY (`id`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
 
+CREATE TABLE `replies` (
+  `title` varchar(100) NOT NULL,
+  `body` text NOT NULL,
+  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+  `user` text NOT NULL,
+  `right` int(10) NOT NULL DEFAULT '0',
+  `attach` varchar(100) NOT NULL DEFAULT '0',
+  `refererId` varchar(50) NOT NULL,
+  `sticky` int(1) NOT NULL DEFAULT '0',
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  `format` varchar(10) NOT NULL DEFAULT 'bbcode',
+  `cat` varchar(25) NOT NULL DEFAULT 'replies',
+  PRIMARY KEY (`id`),
+  FULLTEXT KEY `title` (`title`,`body`)
+) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=utf8;
+INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('headline','inserttextas','2015-08-06 09:21:11','admin','0','0','25','0','1','bbcode','replies');
+INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','inserttext','2015-08-07 14:56:01','guest','0','0','25','0','3','bbcode','replies');
+INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('uberschrift','Text einfügen','2015-08-08 07:23:47','admin','0','0','4','0','4','bbcode','replies');
+INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','Text einfügen #ö+#ü+äö','2015-09-22 19:03:00','admin','0','0','14','0','5','bbcode','');
+INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','Text einfügen','2015-10-07 18:34:13','admin','0','0','22','0','6','bbcode','replies');
+INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','Text einfügendfgdfg','2015-10-07 18:34:43','admin','0','0','22','0','7','bbcode','replies');
+INSERT INTO `replies` (`title`,`body`,`date`,`user`,`right`,`attach`,`refererId`,`sticky`,`id`,`format`,`cat`) values('Überschrift','Text einfügendgdfgdfgd','2015-10-07 18:34:55','admin','0','0','22','0','8','bbcode','replies');
+
 CREATE TABLE `reserved_words` (
   `reserved_word` varchar(50) DEFAULT NULL,
   `id` int(11) NOT NULL AUTO_INCREMENT,
@@ -471,13 +582,74 @@ INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARYING','221');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHILE','222');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('XOR','223');
 
-CREATE TABLE `users` (
-  `pass` text NOT NULL,
-  `user` varchar(10) NOT NULL,
-  `right` int(1) NOT NULL DEFAULT '0',
-  `sid` varchar(200) DEFAULT NULL,
-  `ip` varchar(50) DEFAULT NULL,
+CREATE TABLE `submenu_database` (
+  `title` varchar(100) NOT NULL DEFAULT '',
+  `action` varchar(100) NOT NULL DEFAULT '',
+  `src` varchar(100) NOT NULL DEFAULT 'link.gif',
+  `right` int(11) NOT NULL DEFAULT '0',
+  `submenu` varchar(100) DEFAULT NULL,
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
-) ENGINE=MyISAM AUTO_INCREMENT=14 DEFAULT CHARSET=utf8;
-INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','123','dd','1');
\ No newline at end of file
+) ENGINE=MyISAM AUTO_INCREMENT=24 DEFAULT CHARSET=utf8;
+INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowProcesslist','ShowProcesslist','','5','','5');
+INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowVariables','ShowVariables','','5','','6');
+INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowDumpDatabase','ShowDumpDatabase','','5','','4');
+INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowTables','showTables','','5','','2');
+INSERT INTO `submenu_database` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('ShowUsers','ShowUsers','','5','','3');
+
+CREATE TABLE `submenuadmin` (
+  `title` varchar(100) NOT NULL DEFAULT '',
+  `action` varchar(100) NOT NULL DEFAULT '',
+  `src` varchar(100) NOT NULL DEFAULT 'link.gif',
+  `right` int(11) NOT NULL DEFAULT '0',
+  `submenu` varchar(100) DEFAULT NULL,
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  PRIMARY KEY (`id`)
+) ENGINE=MyISAM AUTO_INCREMENT=18 DEFAULT CHARSET=utf8;
+INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('settings','settings','link.gif','5','','2');
+INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('navigation','editTreeview','','5','','4');
+INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('env','env','link.gif','5','','6');
+INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('Editlinks','linkseditTreeview','link.gif','5','','5');
+INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('Explorer','showDir','link.gif','5','','1');
+INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('trash','trash','','6','','7');
+INSERT INTO `submenuadmin` (`title`,`action`,`src`,`right`,`submenu`,`id`) values('translate','translate','link.png','5','','3');
+
+CREATE TABLE `trash` (
+  `table` varchar(50) NOT NULL DEFAULT '',
+  `oldId` bigint(50) NOT NULL DEFAULT '0',
+  `title` varchar(100) NOT NULL DEFAULT '',
+  `body` text NOT NULL,
+  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+  `user` text NOT NULL,
+  `right` int(11) NOT NULL DEFAULT '0',
+  `attach` varchar(100) NOT NULL DEFAULT '0',
+  `cat` varchar(25) NOT NULL DEFAULT 'main',
+  `action` varchar(50) NOT NULL DEFAULT 'news',
+  `sticky` int(1) NOT NULL DEFAULT '0',
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  `format` varchar(10) NOT NULL DEFAULT 'bbcode',
+  `refererId` int(11) NOT NULL,
+  PRIMARY KEY (`id`),
+  FULLTEXT KEY `title` (`title`,`body`)
+) ENGINE=MyISAM AUTO_INCREMENT=8 DEFAULT CHARSET=utf8;
+
+CREATE TABLE `users` (
+  `pass` text NOT NULL,
+  `user` varchar(25) NOT NULL DEFAULT '',
+  `date` date NOT NULL DEFAULT '0000-00-00',
+  `email` varchar(100) NOT NULL DEFAULT '',
+  `right` int(11) NOT NULL DEFAULT '0',
+  `name` varchar(100) NOT NULL DEFAULT '',
+  `firstname` varchar(100) NOT NULL DEFAULT '',
+  `street` varchar(100) DEFAULT NULL,
+  `city` varchar(100) DEFAULT NULL,
+  `postcode` varchar(20) DEFAULT NULL,
+  `phone` varchar(50) DEFAULT NULL,
+  `sid` varchar(200) DEFAULT NULL,
+  `ip` varchar(50) DEFAULT NULL,
+  `cats` text,
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  PRIMARY KEY (`id`)
+) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
+INSERT INTO `users` (`pass`,`user`,`date`,`email`,`right`,`name`,`firstname`,`street`,`city`,`postcode`,`phone`,`sid`,`ip`,`cats`,`id`) values('guest','guest','0000-00-00','','0','','',NULL,NULL,NULL,NULL,'123','dd','news','1');
+
