@@ -6,7 +6,7 @@ use HTML::Entities;
 use vars qw( 
   $m_dbh
   $m_dsn
-  $m_sDefaultClass 
+  $m_sDefaultClass
   @EXPORT_OK
   @ISA 
   %m_hFunctions
@@ -18,14 +18,15 @@ require Exporter;
 use DBI::Library qw(:all $m_dbh $m_dsn);
 @DBI::Library::Database::ISA    = qw(DBI::Library Exporter);
 @DBI::Library::Database::EXPORT = qw(useexecute);
-@DBI::Library::Database::EXPORT_OK = qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists addUser hasAcount isMember right checkPass checkSession setSid getName initDB checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
+@DBI::Library::Database::EXPORT_OK = qw(fulltext searchDB rss readMenu deleteMessage reply editMessage addMessage getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists addUser hasAcount isMember right checkPass checkSession setSid getName initDB checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
 %DBI::Library::Database::EXPORT_TAGS = (
-    'all' => [ qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName initDB tableLength tableExists useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)],
+    'all' => [ qw(fulltext searchDB rss readMenu deleteMessage reply editMessage addMessage
+ getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName initDB tableLength tableExists useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)],
     'dynamic' => [qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute)],
     'independent' => [qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute fetch_string)],
     'lze' => [ qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue) ],
 );
-$DBI::Library::Database::VERSION = '0.87';
+$DBI::Library::Database::VERSION = '0.89';
 $m_nSecs                         =  10;
 
 =head1 NAME
@@ -106,21 +107,21 @@ sub setSid
 
 =head2 checkSession
 
-    $bool = $m_oDatabase->checkSession($m_sUser,$m_sSid);
+    $bool = $m_oDatabase->checkSession($sUser,$m_sSid);
 
 =cut
 
 sub checkSession
 {
     my ($self, @p) = getSelf(@_);
-    my $m_sUser = shift @p;
+    my $sUser = shift @p;
     my $ssid    = shift @p;
     my $ip      = shift @p;
     my $return  = 0;
-    if (length($m_sUser) > 3 && length($ssid) > 3) {
+    if (length($sUser) > 3 && length($ssid) > 3) {
         my $sql = 'select sid from  users where  user = ?';
         my $sth = $m_dbh->prepare($sql);
-        $sth->execute($m_sUser) or warn $m_dbh->errstr;
+        $sth->execute($sUser) or warn $m_dbh->errstr;
         my $session = $sth->fetchrow_array();
         $sth->finish();
         $return = 1 if (defined $session && defined $ssid && $ssid eq $session);
@@ -154,7 +155,7 @@ sub checkPass
 
 =head2 right()
 
-      $nRight = right($m_sAction,$m_sUsername);
+      $nRight = right($m_sAction,$sUsername);
 
 =cut
 
@@ -225,21 +226,21 @@ sub catright
 
 =head2 isMember
 
-      isMember($m_sUser);
+      isMember($sUser);
 
 =cut
 
 sub isMember
 {
     my ($self, @p) = getSelf(@_);
-    my $m_sUser = lc $p[0];
-    if (defined $m_sUser)
+    my $sUser = lc $p[0];
+    if (defined $sUser)
     {
         my $sth = $m_dbh->prepare('SELECT user  FROM users where user = ?') or warn $m_dbh->errstr;
-        $sth->execute($m_sUser);
+        $sth->execute($sUser);
         my ($member) = $sth->fetchrow_array();
         $sth->finish();
-        return defined $member ? ($m_sUser eq $member) ? 1 : 0 : 0;
+        return defined $member ? ($sUser eq $member) ? 1 : 0 : 0;
     }
     else 
     {
@@ -854,6 +855,384 @@ sub GetColumns
     return $return;
 }
 
+
+=head2 addMessage
+
+     my %message = (
+
+          thread => $thread,
+
+          title => $headline,
+
+          body  => $body,
+
+          thread => $thread,
+
+          cat    => $cat,
+
+          attach => $sra,
+
+          format => $format,
+
+          id => $id,
+
+          user => $sUser,
+
+          attach => $m_sFilename,
+
+          ip => remote_addr(),
+
+
+     );
+
+     my $id = addMessage(\%message);
+
+=cut
+
+sub addMessage
+{
+    my ($self, @p) = getSelf(@_);
+    if ($self->checkFlood($p[0]->{ip})) {
+        my $thread = defined $p[0]->{thread} ? $p[0]->{thread} : 'trash';
+        $thread = ($thread =~ /^(\w{3,50})$/) ? $1 : 'trash';
+        $thread = $m_dbh->quote_identifier($thread);
+        my $headline = defined $p[0]->{title} ? $p[0]->{title} : 'headline';
+        $headline = ($headline =~ /^(.{3,100})$/) ? $1 : 'Invalid headline';
+        my $sUser   = defined $p[0]->{user}   ? $p[0]->{user}   : 'guest';
+        my $body      = defined $p[0]->{body}   ? $p[0]->{body}   : 'Body';
+        my $cat       = defined $p[0]->{cat}    ? $p[0]->{cat}    : 'news';
+        my $rght      = $self->catright($cat);
+        my $attach    = defined $p[0]->{attach} ? $p[0]->{attach} : 0;
+        my $format    = defined $p[0]->{format} ? $p[0]->{format} : 'bbcode';
+        my $m_sAction = defined $p[0]->{action} ? $p[0]->{action} : 'news';
+        my $sql       = "insert into $thread (`title`,`body`,`attach`,`cat`,`right`,`user`,`action`,`format`) values(?,?,?,?,?,?,?,?)";
+        my $sth       = $m_dbh->prepare($sql);
+        $sth->execute($headline, $body, $attach, $cat, $rght, $sUser, $m_sAction, $format) or warn $m_dbh->errstr;
+        my $id = $m_dbh->last_insert_id(undef, undef, qw(news news_id));
+        $sth->finish();
+        return $id;
+    } else {
+        return 0;
+    }
+}
+
+=head2 editMessage()
+
+     my %message = (
+
+          thread => $thread,
+
+          title => $headline,
+
+          body  => $body,
+
+          thread => $thread,
+
+          cat    => $cat,
+
+          attach => $sra,
+
+          format => $format,
+
+          id => $id,
+
+          user => $sUser,
+
+          attach => $m_sFilename,
+
+          ip => remote_addr(),
+
+     );
+
+     editMessage(\%message);
+
+=cut
+
+sub editMessage
+{
+    my ($self, @p) = getSelf(@_);
+    if ($self->checkFlood($p[0]->{ip})) {
+        my $thread = defined $p[0]->{thread} ? $p[0]->{thread} : 'trash';
+        $thread = ($thread =~ /^(\w{3,50})$/) ? $1 : 'trash';
+        $thread = $m_dbh->quote_identifier($thread);
+        my $refid    = defined $p[0]->{id}    ? $p[0]->{id}    : 1;
+        my $headline = defined $p[0]->{title} ? $p[0]->{title} : 'headline';
+        $headline = ($headline =~ /^(.{3,100})$/) ? $1 : 'Invalid headline';
+        my $sUser = defined $p[0]->{user}   ? $p[0]->{user}   : 'guest';
+        my $body    = defined $p[0]->{body}   ? $p[0]->{body}   : 'Body';
+        my $attach  = defined $p[0]->{attach} ? $p[0]->{attach} : 0;
+        my $format  = defined $p[0]->{format} ? $p[0]->{format} : 'bbcode';
+        my $cat     = defined $p[0]->{cat}    ? $p[0]->{cat}    : 'news';
+        my $up =
+          defined $p[0]->{uploadpath}
+          ? $p[0]->{uploadpath}
+          : '/srv/www/htdocs/downloads';
+
+        if ($attach ne '0.0') {
+            my $sql_insert = qq/update $thread set title =?, body =? , attach= ?,format =?,user =?,cat =?,`right` =? where id = ?;/;
+            my $sth        = $m_dbh->prepare($sql_insert);
+            $sth->execute($headline, $body, $attach, $format, $sUser, $cat, $self->catright($cat), $refid) or warn $m_dbh->errstr;
+            $sth->finish();
+        } else {
+            my $sql_insert = qq/update $thread set title =?, body = ? ,format = ?,user = ?,cat = ?,`right` =?  where id = ?;/;
+            my $sth        = $m_dbh->prepare($sql_insert);
+            $sth->execute($headline, $body, $format, $sUser, $cat, $self->catright($cat), $refid) or warn $m_dbh->errstr;
+            $sth->finish();
+        }
+    }
+}
+
+=head2 reply
+
+     my %reply =(
+
+          title => $headline,
+
+          body => $body,
+
+          id => $reply,
+
+          user => $sUser,
+
+          attach =>  $sra,
+
+          format => $html,
+
+          ip => remote_addr(),
+
+     );
+
+     reply(\%reply);
+
+=cut
+
+
+sub reply
+{
+    my ($self, @p) = getSelf(@_);
+#     if ($self->checkFlood($p[0]->{ip})) {
+        my $headline = defined $p[0]->{title} ? $p[0]->{title} : 'headline';
+        $headline = ($headline =~ /^(.{3,100})$/) ? $1 : 'Invalid headline';
+        my $sUser = defined $p[0]->{user}   ? $p[0]->{user}   : 'guest';
+        my $body    = defined $p[0]->{body}   ? $p[0]->{body}   : 'Body';
+        my $attach  = defined $p[0]->{attach} ? $p[0]->{attach} : 0;
+        my $format  = defined $p[0]->{format} ? $p[0]->{format} : 'bbcode';
+        my $refid   = defined $p[0]->{id}     ? $p[0]->{id}     : 1;
+        my $sql     = "insert into replies (`title`,`body`,`attach`,`right`,`user`,`refererId`,`format`) values(?,?,?,?,?,?,?)";
+        my $sth     = $m_dbh->prepare($sql);
+        $sth->execute($headline, $body, $attach, $self->topicright($refid), $sUser, $refid, $format) or warn $m_dbh->errstr;
+        $sth->finish();
+#     }
+}
+
+=head2 deleteMessage
+
+      $bool = $self->deleteMessage($table,$id);
+
+=cut
+
+sub deleteMessage
+{
+    my ($self, @p) = getSelf(@_);
+    my $p_sTable   = $p[0];
+    my $id         = $p[1];
+    my $sql_backup = "select * from $p_sTable  Where id  = '$id'";
+    my $sth_backup = $m_dbh->prepare($sql_backup);
+    $sth_backup->execute();
+    my $backup    = $sth_backup->fetchrow_hashref();
+    my $c         = ($p_sTable eq 'replies') ? 'replies' : $backup->{cat};
+    my $refererId = ($p_sTable eq 'replies') ? $backup->{refererId} : 0;
+    my $sql_trash = "insert into `trash`  (`table`,`oldId`,`title`,`body`,`date`,`user`,`right`,`attach`,`cat`,`sticky`,`refererId`,`format`) values(?,?,?,?,?,?,?,?,?,?,?)";
+    my $sth_trash = $m_dbh->prepare($sql_trash);
+    $sth_trash->execute($p_sTable, $id, $backup->{title}, $backup->{body}, $backup->{date}, $backup->{user}, $backup->{right}, $backup->{attach}, $c, $backup->{sticky}, $refererId, $backup->{format});
+    my $sql_delete = "DELETE FROM $p_sTable Where id  = '$id'";
+    my $sth        = $m_dbh->prepare($sql_delete);
+    $sth->execute() or warn $m_dbh->errstr;
+    $sth->finish();
+    return 1;
+}
+
+=head2 readMenu()
+
+      @menu = $m_oDatabase->readMenu($sThread,$nRight,$nStart,$nEnd);
+
+=cut
+
+sub readMenu
+{
+    my ($self, @p) = getSelf(@_);
+    my $thread   = $p[0];
+    my $p_nRight = $p[1];
+    my $p_nStart = $p[2];
+    my $p_nEnd   = $p[3];
+    $p_nStart = 0  unless (defined $p_nStart);
+    $p_nEnd   = 10 unless (defined $p_nEnd);
+    my $limit = $p_nEnd - $p_nStart;
+    my $sql_read = qq/select title,id from  $thread where `right` <= $p_nRight order by date desc  LIMIT $p_nStart , $limit/;
+    my $sth      = $m_dbh->prepare($sql_read);
+    $sth->execute();
+    my @output;
+
+    while (my @data = $sth->fetchrow_array()) {
+        my $headline = $data[0];
+        my $id       = $data[1];
+        $headline =~ s/(.{15}).+/$1.../;
+        my $nl = "javascript:requestURI('$ENV{SCRIPT_NAME}?action=$thread&amp;von=$p_nStart&amp;bis=$p_nEnd#$id');";
+        push @output,
+          {
+            text => $headline,
+            href => $nl,
+          };
+    }
+    $sth->finish();
+    return @output;
+}
+
+=head2 rss()
+
+      $rss = $m_oDatabase->rss($thread,int start);
+
+=cut
+
+sub rss
+{
+    my ($self, @p) = getSelf(@_);
+    my $thread = $p[0];
+    $thread = 'news' unless (defined $thread);
+    my $p_nStart = $p[1];
+    $p_nStart = 0 unless (defined $p_nStart);
+    my $time     = localtime;
+    my $sql_read = qq/select *from  $thread  where `right` = '0' order by id desc  LIMIT $p_nStart , 10/;
+    my $sth      = $m_dbh->prepare($sql_read);
+    $sth->execute();
+    my $description = translate('description');
+    my @output;
+    push @output,
+qq(Content-Type: text/xml\n\n<?xml version="1.0" encoding="UTF-8"?>\n<rss xmlns:atom="http://www.w3.org/2005/Atom" version="2.0"><channel><title>$thread</title>\n<description>$description</description>\n<link>$m_sServerName</link>\n<language>de</language>\n<pubDate>$time</pubDate>\n</channel>\n);
+
+    while (my @data = $sth->fetchrow_array()) {
+        my $headline = $data[0];
+        my $body     = $data[1];
+        my $href     = $data[9];
+        my $link = "javascript:requestURI('$m_sServerName?action=$thread;#$href')";
+        push @output, "\n<item>\n<title>$headline</title>\n<link>$link</link>\n<description>$body</description></item>\n";
+    }
+    push @output, "\n</rss>";
+    $sth->finish();
+    return @output;
+}
+
+=head2 searchDB()
+
+       searchDB($query,$column,$table,$rigt,$start,$end);
+
+regexp search in tabelle ...
+
+=cut
+
+sub searchDB
+{
+    my ($self, @p) = getSelf(@_);
+    my $p_sQuery = $p[0];
+    eval("return 0 if/($p_sQuery)/;");
+    return "Invalid regexp : $@" if $@;
+    $p_sQuery = $self->quote($p_sQuery);
+    my $p_sCol = $p[1];
+    $p_sCol = $m_dbh->quote_identifier($p_sCol);
+    my $p_sTable = $p[2];
+    $p_sTable = $m_dbh->quote_identifier($p_sTable);
+    my $p_nRight = $p[3];
+    my $p_nStart = $p[4] ? $p[4] : 0;
+    my $p_nEnd   = $p[5] ? $p[5] : 100;
+    my $limit    = $p_nEnd - $p_nStart;
+    $p_nRight = $p_nRight =~ /(\d+)/ ? $1 : 0;
+    $p_nStart = $p_nStart =~ /(\d+)/ ? $1 : 0;
+    $limit    = $limit    =~ /(\d+)/ ? $1 : 10;
+    my $sql_select = "SELECT * FROM $p_sTable WHERE  `right` <= $p_nRight  && ( $p_sCol REGEXP $p_sQuery || title REGEXP $p_sQuery )  order by date desc LIMIT $p_nStart , $limit ";
+    my $b          = '<table align="center" summary="layoutSearch" border="0" cellpadding="0" cellspacing="0" width="100%"><tr><td class="caption">Title</td><td class="caption">User</td><td class="caption">Datum</td></tr>';
+    my @messages   = $self->fetch_AoH($sql_select);
+
+    for (my $i = 0; $i <= $#messages; $i++) {
+        my $body = $messages[$i]->{body};
+        if (!utf8::is_utf8($body)) {
+            utf8::decode($body);
+        }
+        $body =~ s/\[([^\]])+\]//gs;
+        $body =~ s?<[^>]+>??gs;
+        my $j = index $body, /$p[0]/;
+        $j = $j > 50 ? $j - 50 : 0;
+        $body = substr($body, $j, 150);
+        $body = encode_entities($body);
+        $body =~ s?($p[0])?<span style="color:red;">$1</span>?ig;
+
+        if (!utf8::is_utf8($messages[$i]->{title})) {
+            utf8::decode($messages[$i]->{title});
+        }
+        $messages[$i]->{title} = encode_entities($messages[$i]->{title});
+        $messages[$i]->{title} =~ s?($p[0])?<span style="color:red;">$1</span>?ig;
+
+        my $link = "javascript:requestURI('$ENV{SCRIPT_NAME}?action=showthread&reply=$messages[$i]->{id}','showthread','showthread');";
+        $b .=
+qq(<tr><td class="values"><a href="$link" class="menuLink">$messages[$i]->{title}</a></td><td class="values">$messages[$i]->{user}</td><td align="right" class="values"><font size="-1">$messages[$i]->{date}</font></td></tr><tr><td colspan="3"><font size="-2">$body</font></td></tr>);
+    }
+    $b .= '</table>';
+    return $b;
+}
+
+=head2 fulltext()
+
+      @messages = fulltext(query,table);
+
+fulltextsuche in tabelle ...
+
+=cut
+
+sub fulltext
+{
+    my ($self, @p) = getSelf(@_);
+    my $p_sQuery = $p[0];
+    eval("return 0 if/($p_sQuery)/;");
+    return "Invalid Query : <br/>" if $@;
+    $p_sQuery = $self->quote($p_sQuery);
+    my $p_sTable = $p[1];
+    $p_sTable = $m_dbh->quote_identifier($p_sTable);
+    my $p_nRight = $p[2];
+    my $p_nStart = $p[3] ? $p[3] : 0;
+    my $p_nEnd   = $p[4] ? $p[4] : 100;
+    my $limit    = $p_nEnd - $p_nStart;
+    $p_nRight = $p_nRight =~ /(\d+)/ ? $1 : 0;
+    $p_nStart = $p_nStart =~ /(\d+)/ ? $1 : 0;
+    $limit    = $limit    =~ /(\d+)/ ? $1 : 10;
+    my $b        = '<table align="center" summary="fulltext" border="0" cellpadding="2" cellspacing="0" width="100%"><tr><td class="caption">Title</td><td class="caption">User</td><td class="caption">Datum</td></tr>';
+    my @messages = $self->fetch_AoH("SELECT * FROM $p_sTable  where `right` <= $p_nRight and MATCH (title,body) AGAINST($p_sQuery) order by date desc LIMIT $p_nStart , $limit");
+
+    for (my $i = 0; $i <= $#messages; $i++) {
+        my $body = $messages[$i]->{body};
+        if (!utf8::is_utf8($body)) {
+            utf8::decode($body);
+        }
+        $body =~ s/\[([^\]])+\]//gs;
+        $body =~ s?<[^>]+>??gs;
+        my $j = index $body, $p_sQuery;
+        $j = $j > 50 ? $j - 50 : 0;
+        $body = substr($body, $j, 150);
+        $body = encode_entities($body);
+        $body =~ s/($p[0])/<span style="color:red;">$1<\/span>/ig;
+
+        if (!utf8::is_utf8($messages[$i]->{title})) {
+            utf8::decode($messages[$i]->{title});
+        }
+        $messages[$i]->{title} = encode_entities($messages[$i]->{title});
+        $messages[$i]->{title} =~ s/($p[0])/<span style="color:red;">$1<\/span>/ig;
+        my $link = "javascript:requestURI('$ENV{SCRIPT_NAME}?action=showthread&reply=$messages[$i]->{id}','showthread','showthread')";
+        $b .=
+qq(<tr><td class="values"><a href="$link" class="menuLink">$messages[$i]->{title}</a></td><td class="values">$messages[$i]->{user}</td><td align="right" class="values"><font size="-1">$messages[$i]->{date}</font></td></tr><tr><td colspan="3"><font size="-2">$body</font></td></tr>);
+    }
+    $b .= '</table>';
+    return $b;
+}
+
+
 =head2 getSelf()
 
     getSelf or CGI
