@@ -5,9 +5,9 @@ require Exporter;
 use vars qw($config $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Config::EXPORT  = qw(loadConfig saveConfig $config);
 @ISA                           = qw(Exporter);
-$MySQL::Admin::Config::VERSION = '0.87';
+$MySQL::Admin::Config::VERSION = '0.89';
 $DefaultClass                  = 'MySQL::Admin::Config' unless defined $MySQL::Admin::Config::DefaultClass;
-$defaultconfig                 = '%CONFIG%';
+$defaultconfig                 = '%PATH%/config/config.pl';
 
 =head1 NAME
 
