@@ -11,17 +11,21 @@ use MySQL::Admin::Settings;
 use MySQL::Admin::Translate;
 use MySQL::Admin::Config;
 use MySQL::Admin::Session;
+use HTML::Menu::TreeView qw(:all);
+use HTML::Editor::BBCODE;
+use CGI::QuickForm;
+use HTML::Editor;
 use Encode;
 use Fcntl qw(:flock);
 use Symbol;
 use URI::Escape;
-# use diagnostics;
-#use CGI::Carp qw(fatalsToBrowser);
+use diagnostics;
+use CGI::Carp qw(fatalsToBrowser);
 require Exporter;
-use vars qw( $DefaultClass $ACCEPT_LANGUAGE @EXPORT @ISA $m_bMod_perl %m_hUniq $m_hrParams $m_hrSettings $m_hrLng $m_nStart $m_nEnd $m_nRight $m_sAction $m_sSid $m_sStyle $m_sTitle $m_sUser $m_sContent $m_sCurrentDb $m_sCurrentHost  $m_sCurrentUser $m_sCurrentPass  $m_sAjax  $m_nSkipCaptch );
-@MySQL::Admin::GUI::EXPORT  = qw( ContentHeader Body ChangeDb Unique );
+use vars qw( $DefaultClass $ACCEPT_LANGUAGE @EXPORT @ISA $m_bMod_perl %m_hUniq $m_hrParams $m_hrSettings $m_hrLng $m_nStart $m_nEnd $m_nRight $m_sAction $m_sSid $m_sStyle $m_sTitle $m_sUser $m_sCurrentDb $m_sCurrentHost  $m_sCurrentUser $m_sCurrentPass $m_nSkipCaptch );
+@MySQL::Admin::GUI::EXPORT  = qw( ContentHeader Body ChangeDb Unique openFile action applyRights maxlength);
 @ISA                        = qw( Exporter MySQL::Admin );
-$MySQL::Admin::GUI::VERSION = '0.87';
+$MySQL::Admin::GUI::VERSION = '0.89';
 $m_bMod_perl                = ( $ENV{MOD_PERL} ) ? 1 : 0;
 local $^W = 0;
 our @m_processlist;
@@ -56,7 +60,7 @@ sub ContentHeader
     my $m_hrSettingsfile = shift;
     init($m_hrSettingsfile)  unless $m_bMod_perl and $m_bFirstTime;
    
-    $m_sAjax = qq(<?xml version="1.0" encoding="UTF-8"?>\n<xml>);
+    print qq(<?xml version="1.0" encoding="UTF-8"?>\n<xml>);
     $m_nSkipCaptch = 0;
 
     #todo klären wiso m_hrLng durch init nicht gesetzt wird.
@@ -78,7 +82,7 @@ sub ContentHeader
         param('m_ChangeCurrentDb')
       ? param('m_ChangeCurrentDb')
       : $m_hrSettings->{database}{CurrentDb};
-    $m_sAction =  param('action') ? param('action') : 'ShowDatabases';#todo settings
+    $m_sAction =  param('action') ? param('action') : $m_hrSettings->{defaultAction};
 
     $m_sAction = ( $m_sAction =~ /^(\w{3,50})$/ ) ? $1 : $m_sAction;
     $m_sCurrentHost = param('m_shost') ? param('m_shost') : $m_hrSettings->{database}{CurrentHost};
@@ -101,7 +105,7 @@ sub ContentHeader
     $m_sUser = $m_oDatabase->getName($m_sSid);
     $m_sUser = defined $m_sUser ? $m_sUser : 'guest';
     my @aCookies;
-    if ( $m_sAction eq 'logout'  or ( $m_sUser  eq 'guest' and  $m_sAction ne 'login' ) ) {
+    if ( $m_sAction eq 'logout'  or ( $m_sUser  eq 'guest' and  $m_sAction ne 'login' ) ){
         my $cookie = cookie(
             -name    => 'sid',
             -value   => '',
@@ -115,8 +119,7 @@ sub ContentHeader
             -cookie  => [@aCookies]
         );
         $m_sUser   = 'guest';
-        $m_sSid    = '123';
-        $m_sAction = 'showLogin';
+        $m_sAction = 'showLogin' if $m_hrSettings->{loginscreen};
     }elsif ( $m_sAction eq 'login') {
         my $ip = remote_addr();
         my $u  = param('user');
@@ -164,7 +167,7 @@ sub ContentHeader
                 -charset => 'UTF-8',
             );
         }
-        $m_sAction = 'ShowDatabases';
+        $m_sAction = $m_hrSettings->{defaultAction};
     }else {
         print header(
             -type    => 'text/xml',
@@ -194,26 +197,26 @@ sub Body
     $m_nRight   = $m_oDatabase->userright($m_sUser);
     $m_nRight   = defined $m_nRight ? $m_nRight: 0;
     my $exploit = 0;
-    my @action_set = $m_oDatabase->fetch_AoH("select actions.action,actions.file,actions.title,actions.right,actions.sub,actions_set.output_id from actions join actions_set on actions.action = actions_set.foreign_action where actions_set.action = ?",$m_sAction);
+    my @action_set = $m_oDatabase->fetch_AoH("select actions.action,actions.file,actions.title,actions.right,actions.sub,actions_set.output_id from actions join actions_set on actions.action = actions_set.foreign_action where actions_set.action = ? || actions_set.action = 'default'",$m_sAction);
     $exploit = 1 if $@;
     for( my $i = 0; $i <= $#action_set; $i++ ) {
-	$m_sContent = "";#change main Db
 	my $action = $action_set[$i];
 	$m_sTitle = $action->{title};
 	if ( $m_nRight >= $action->{right} ){
+	  print qq|<output id="$action->{output_id}"><![CDATA[|;
 	  do("$m_hrSettings->{cgi}{bin}/Content/$action->{file}") if  -e "$m_hrSettings->{cgi}{bin}/Content/$action->{file}";
-	  eval($action->{sub}) if $action->{sub} ne 'main';	  
-	  $m_sAjax .= qq|<output id="errorMessage"><![CDATA[$@]]></output>| if $@;
-	  $m_sAjax .= qq|<output id="$action->{output_id}"><![CDATA[$m_sContent]]></output>|;
+	  eval($action->{sub}) if $action->{sub} ne 'main';
+	  print q|]]></output>|;
+	  print qq|<output id="errorMessage"><![CDATA[$@]]></output>| if $@;
 	}else{
 	  $exploit = 1;
 	}
     }
     if($exploit) {
-        $m_sContent = "";
+        print qq|<output id="content"><![CDATA[|;
         do("$m_hrSettings->{cgi}{bin}/Content/exploit.pl");
-        $m_sAjax .= qq|<output id="errorMessage"><![CDATA[$@ ]]></output>| if $@;
-        $m_sAjax .= qq|<output id="content"><![CDATA[$m_sContent]]></output>| if $m_sContent;
+        print q|]]></output>|;
+        print qq|<output id="errorMessage"><![CDATA[$@ ]]></output>| if $@;
     }else{#change main Db
 	ChangeDb(
 	    {
@@ -225,7 +228,7 @@ sub Body
 	);
     }
     clearSession();
-    return $m_sAjax . '</xml>';
+    print  '</xml>';
 }
 
 =head2 ChangeDb
@@ -274,6 +277,117 @@ sub Unique
     return $unic;
 }
 
+=head2 openFile
+
+        my $file = openFile("filename");
+
+=cut
+
+sub openFile
+{
+    my $file = shift;
+    if (-e $file) {
+        use Fcntl qw(:flock);
+        use Symbol;
+        my $fh = gensym;
+        open $fh, $file or warn "$!: $file $/";
+        seek $fh, 0, 0;
+        my $lines;
+        while (my $line = <$fh>) {
+            $lines .= $line;
+        }
+        close $fh;
+        return $lines;
+    } else {
+        warn "file exestiert nicht $/";
+    }
+}
+
+=head2 applyRights()
+
+updates the user rights to a treeviewLink
+
+        applyRights(\@tree);
+
+=cut
+
+sub applyRights
+{
+    my $t = shift;
+    for (my $i = 0; $i < @$t; $i++) {
+        my $r = @$t[$i]->{right} ? @$t[$i]->{right} : 0;
+        if ($r > $m_nRight) {
+            undef @$t[$i];
+        } elsif (defined @{@$t[$i]->{subtree}}) {
+            applyRights(\@{@$t[$i]->{subtree}});
+        }
+    }
+}
+
+=head2 action
+
+        my %action = {
+
+                title => '',
+
+                src   => 'location',
+
+                location => '',
+
+                style => 'optional',
+
+        };
+
+        print action{\%action);
+
+=cut
+
+sub action
+{
+    my $hash     = shift;
+    my $title    = $hash->{title} if (defined $hash->{title});
+    my $src      = $hash->{src} if (defined $hash->{src});
+    my $location = $hash->{location} if (defined $hash->{location});
+    if($location !~/^javascript:/){
+       $location = "javascript:requestURI('$location&ajax=true',this.id,'$title')";
+    }
+    return
+qq(<table align ="left" border ="0" cellpadding ="0" cellspacing="0" summary="layoutMenuItem"><tr><td valign ="middle"><img src="/style/$m_sStyle/buttons/$src" width="20" height="20" border="0" alt="" title="$title" style="cursor:pointer;font-size:14px;vertical-align:bottom;"/></td><td><a class="link" href="$location"  style='font-size:14px;vertical-align:bottom;'>$title</a></td></tr></table>);
+}
+
+=head2  maxlength()
+     
+     maxlength($length ,\$text);
+
+=cut
+
+sub maxlength
+{
+    my $maxWidth = shift;
+    ++$maxWidth;
+    my $txt = shift;
+    if (length($$txt) > $maxWidth) {
+        my $maxLength = $maxWidth;
+        my $i++;
+        while ($i < length($$txt)) {
+            if (substr($$txt, $i, 1) eq "<") {
+                $maxLength = $maxWidth;
+                do {$i++} while (substr($$txt, $i, 1) ne ">" and $i < length($$txt));
+            }
+            if (substr($$txt, $i, 1) eq "&") {
+                $maxLength = $maxWidth;
+                do {$i++} while (substr($$txt, $i, 1) ne ";" and $i < length($$txt));
+            }
+            $maxLength = (substr($$txt, $i, 1) =~ /\S/) ? --$maxLength : $maxWidth;
+            if ($maxLength eq 0) {
+                substr($$txt, $i, 1) = " ";
+                $maxLength = $maxWidth;
+            }
+            $i++;
+        }
+    }
+}
+
 =head1 SEE ALSO
 
 L<CGI> L<MySQL::Admin>
