@@ -6,9 +6,9 @@ use vars qw( $session $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Session::EXPORT = qw(loadSession saveSession $session);
 use MySQL::Admin::Config;
 @MySQL::Admin::Session::ISA     = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Session::VERSION = '0.87';
+$MySQL::Admin::Session::VERSION = '0.89';
 $DefaultClass                   = 'MySQL::Admin::Session' unless defined $MySQL::Admin::Session::DefaultClass;
-$defaultconfig                  = '%CONFIG%';
+$defaultconfig                  = '%PATH%/config/session.pl';
 
 =head1 NAME
 
