@@ -6,9 +6,9 @@ use vars qw($m_hrSettings $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Settings::EXPORT = qw(loadSettings saveSettings $m_hrSettings);
 use MySQL::Admin::Config;
 @ISA                             = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Settings::VERSION = '0.87';
+$MySQL::Admin::Settings::VERSION = '0.89';
 $DefaultClass                    = 'MySQL::Admin::Settings' unless defined $MySQL::Admin::Settings::DefaultClass;
-$defaultconfig                   = '%CONFIG%';
+$defaultconfig                   = '%PATH%/config/settings.pl';
 
 =head1 NAME
 
