@@ -7,9 +7,9 @@ use vars qw($ACCEPT_LANGUAGE $lang $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Translate::EXPORT = qw(loadTranslate saveTranslate $lang);
 use MySQL::Admin::Config;
 @ISA                              = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Translate::VERSION = '0.87';
+$MySQL::Admin::Translate::VERSION = '0.89';
 $DefaultClass                     = 'MySQL::Admin::Translate' unless defined $MySQL::Admin::Translate::DefaultClass;
-$defaultconfig                    = '%CONFIG%';
+$defaultconfig                    = '%PATH%/config/translate.pl';
 
 =head1 NAME
 
